<?php

declare(strict_types=1);

namespace Drupal\multisite_manager_tool;

/**
 * Provides a helper for multisite system.
 */
class SitesHelper {

  /**
   * Get the list of available multisites.
   */
  public function getMultisiteList():array {
    $sites_directory = DRUPAL_ROOT . '/sites/';
    $sites = [];

    foreach (scandir($sites_directory) as $folder) {
      if ($folder === '.' || $folder === '..' || in_array($folder, ['default', 'all'])) {
        // Ignore some sites.
        continue;
      }
      if (is_dir("$sites_directory$folder") && file_exists("$sites_directory$folder/settings.php")) {
        $sites[$folder] = $folder;
      }
    }

    return $sites;
  }

  /**
   * Check if exist at least one site.
   */
  public function checkIfOneSite():bool {
    return (count($this->getMultisiteList()) > 0);
  }

  /**
   * Execute drush command per site.
   *
   * @param string $site
   *   The site.
   * @param string $command
   *   The command to be executed.
   */
  public function drushCommandSite(string $site, string $command):void {
    $command = "drush --root=" . escapeshellarg(DRUPAL_ROOT) . " --uri=" . escapeshellarg($site) . " " . escapeshellarg($command);
    exec($command, $output, $return_var);
  }

}
